@@ -18,7 +18,7 @@ class MerchantCenterServiceDownException(Exception):
     pass
 
 
-def get_exception_message(merchant_id: str, access_token: Optional[str] = None) -> str:
+def get_exception_message(merchant_id: int, access_token: Optional[str] = None) -> str:
     if access_token:
         return F"We cannot access your Merchant Center account with the id: {merchant_id}. Are you sure you have access and entered correct ID?"
     else:
@@ -64,10 +64,10 @@ def get_mct_account_details(
         response_account_statuses = request_account_statuses.execute()
     # RefreshError is raised when we have invalid merchant_id or we don't have access to the account
     except RefreshError as err:
-        raise MctAccountLostAccessException(get_exception_message(access_token, merchant_id))
+        raise MctAccountLostAccessException(get_exception_message(merchant_id, access_token))
     except HttpError as err:
         if err.resp.status >= 400 and err.resp.status < 500:
-            raise MctAccountLostAccessException(get_exception_message(access_token, merchant_id))
+            raise MctAccountLostAccessException(get_exception_message(merchant_id, access_token))
         else:
             raise MerchantCenterServiceDownException(f"The Merchent Center API does not respond. Thus, we cannot check if we can access your Merchant Center account with the id: {merchant_id}. Please try later" )
     return response_account_statuses['name']
@@ -91,7 +91,7 @@ def check_if_multi_client_account(
         response_account_statuses = request_account_products.execute()
     # RefreshError is raised when we have invalid merchant_id or we don't have access to the account
     except RefreshError as err:
-        raise MctAccountLostAccessException(get_exception_message(access_token, merchant_id))
+        raise MctAccountLostAccessException(get_exception_message(merchant_id, access_token))
     except HttpError as err:
         if err.resp.status >= 400 and err.resp.status < 500:
             raise MctAccountLostAccessException(f"This merchant id ({merchant_id} is for multi acccounts. You can only link sub-accounts.")
